@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: QueueCatalog.py 68067 2006-05-09 15:31:37Z jens $
+$Id: QueueCatalog.py 71311 2006-11-27 08:26:56Z zagy $
 """
 # Python std. lib
 import logging
@@ -254,7 +254,7 @@ class QueueCatalog(Implicit, SimpleItem):
                     )
 
             security_manager = getSecurityManager()
-            if not security_manager.validateValue(ZC):
+            if not security_manager.validate(self, self, self._location, ZC):
                 raise Unauthorized(self._location, ZC)
 
             ZC = aq_base(ZC).__of__(parent)
